@@ -15,8 +15,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from PySide2.QtCore import (
-    Qt, QAbstractTableModel, QModelIndex)
+from PySide2.QtCore import QAbstractTableModel, QModelIndex, Qt
+
 from EmailReminder.Utils import readXMLValue, writeXMLValue
 
 
